Documentation
¶
Overview ¶
Package graph parses and generates build graphs
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ByName ¶
type ByName []*Node
ByName sorts dependencies by name so we can have reproduceable builds.
type Graph ¶
Graph represents a build graph
func New ¶
New returns a new build graph relatvie to the working directory
type Node ¶
type Node struct {
IsRoot bool `json:"-"`
Target build.Rule `json:"-"`
Type string
Parents map[string]*Node `json:"-"`
Label label.Label
Worker string
PriorityCount int
WG sync.WaitGroup
Status build.Status
Cached bool
Start, End int64
Hash string
Output string `json:"-"`
Once sync.Once
sync.Mutex
Children map[string]*Node
// contains filtered or unexported fields
}
Node encapsulates a target and represents a node in the build graph.
func NewNode ¶
NewNode takes a label and a rule and returns it as a Graph Node
Source Files
¶
- graph.go
- hash.go
- node.go
Click to show internal directories.
Click to hide internal directories.